@@ -12,11 +12,11 @@ class Setup():
 
     print("-----------------------------")
 
-    print("The library is installed in")
+    print("  The library is installed in")
     print(rute + '/KrakenOS/')
-    print("for help see Examples directory")
-    print("To change glass catalog modify catalog list in SetupCas.py")
-    print("See User_Manual USER_MANUAL_KrakenOS_Provisional.pdf in:" )
+    print("  For help see Examples directory")
+    print("  To change glass catalog modify catalog list in SetupCas.py")
+    print("  See User_Manual USER_MANUAL_KrakenOS_Provisional.pdf in:" )
     print(print(rute + '/Docs/'))
     print("-----------------------------")
 
